Learn R Programming

GLMMselect (version 1.2.0)

lipcancer_X: The matrix of candidate covariates

Description

This is a matrix with one candidate covariates, which is the proportion of population engaged in agriculture, fishing, or forestry.

Usage

lipcancer_X

Arguments

Format

lipcancer_X

A matrix with 56 observations and 1 covariate.