Learn R Programming

GLMMselect (version 1.2.0)

lipcancer_Y: The vector of observations for lip cancer case study

Description

The observations about the observed number of lip cancer cases in each Scotland county between 1975 and 1980.

Usage

lipcancer_Y

Arguments

Format

lipcancer_Y

A vector with 56 observations.